Class: User
- Inherits:
-
Rubee::SequelObject
- Object
- Rubee::SequelObject
- User
- Defined in:
- lib/app/models/user.rb,
lib/tests/example_models/user.rb
Overview
WARNING: User model is required for JWT authentification If you remove or modify it, make sure all changes are inlined with AuthTokenMiddleware and AuthTokenable modules
Instance Attribute Summary collapse
-
#created ⇒ Object
Returns the value of attribute created.
-
#email ⇒ Object
Returns the value of attribute email.
-
#id ⇒ Object
Returns the value of attribute id.
-
#password ⇒ Object
Returns the value of attribute password.
-
#updated ⇒ Object
Returns the value of attribute updated.
Method Summary
Methods inherited from Rubee::SequelObject
all, #assign_attributes, count, create, dataset, db_set?, #destroy, destroy_all, find, find_first, find_last, find_or_new, first, holds, join, last, limit, offset, order, owns_many, owns_one, paginate, #persisted?, reconnect!, #reload, #save, serialize, #update, validate_before_persist!, where
Methods included from Rubee::DatabaseObjectable
Instance Attribute Details
#created ⇒ Object
Returns the value of attribute created.
5 6 7 |
# File 'lib/app/models/user.rb', line 5 def created @created end |
#email ⇒ Object
Returns the value of attribute email.
5 6 7 |
# File 'lib/app/models/user.rb', line 5 def email @email end |
#id ⇒ Object
Returns the value of attribute id.
5 6 7 |
# File 'lib/app/models/user.rb', line 5 def id @id end |
#password ⇒ Object
Returns the value of attribute password.
5 6 7 |
# File 'lib/app/models/user.rb', line 5 def password @password end |
#updated ⇒ Object
Returns the value of attribute updated.
5 6 7 |
# File 'lib/app/models/user.rb', line 5 def updated @updated end |